@@ -1,5 +1,4 @@
 from enum import IntEnum
-from pathlib import Path
 from typing import List, Optional, Tuple, Union
 
 from pydantic import BaseModel
@@ -15,14 +14,6 @@ class ZenoColumnType(IntEnum):
     WEAK_LABEL = 6
 
 
-class ZenoFunctionType(IntEnum):
-    PREDICTION = 0
-    PREDISTILL = 1
-    POSTDISTILL = 2
-    TRANSFORM = 3
-    METRIC = 4
-
-
 class MetadataType(IntEnum):
     NOMINAL = 0
     CONTINUOUS = 1
@@ -60,12 +51,6 @@ class Report(CamelModel):
     report_predicates: List[ReportPredicate]
 
 
-class ZenoFunction(CamelModel):
-    name: str
-    file_name: Path
-    fn_type: ZenoFunctionType
-
-
 class ZenoColumn(CamelModel):
     column_type: ZenoColumnType
     name: str
